@@ -2,7 +2,8 @@
 #' 
 #' @param x An object of class \code{\link{spwbInput}}.
 #' @param soil A list containing the description of the soil (see \code{\link{soil}}).
-#' @param type Plot type for \code{hydraulics_vulnerabilityCurvePlot}, either \code{"leaf"}, \code{"stem"}, \code{"root"}, \code{"rootlayer"} or \code{"rhizosphere"}).
+#' @param type Plot type for \code{hydraulics_vulnerabilityCurvePlot}, either \code{"leaf"}, 
+#'             \code{"stem"}, \code{"root"} or \code{"rhizosphere"}).
 #' @param psiVec Vector of water potential values to evaluate for the vulnerability curve.
 #' @param relative A flag to relativize vulnerability curves to the [0-1] interval.
 #' @param speciesNames A flag to indicate the use of species names instead of cohort names in plots.
@@ -13,7 +14,7 @@ hydraulics_vulnerabilityCurvePlot<-function(x, soil = NULL, type="leaf",  psiVec
                                             relative = FALSE, speciesNames = FALSE, 
                                             draw = TRUE,  ylim = NULL, xlab = NULL, ylab = NULL) {
   
-  TYPES = c("leaf","stem","root","rootlayer", "rhizosphere")
+  TYPES = c("leaf","stem","root","rhizosphere")
   type = match.arg(type,TYPES)  
   
   cohortnames = row.names(x$cohorts)
